<?php
/**
 *
 * Kuteshop products
 *
 */
if ( !class_exists( 'Products_Widget' ) ) {
	class Products_Widget extends WP_Widget
	{
		function __construct()
		{
			$widget_ops = array(
				'classname'   => 'widget-products kuteshop-widget-products',
				'description' => 'Widget products.',
			);
			parent::__construct( 'widget_products', '1 - Kuteshop Products', $widget_ops );
		}

		function widget( $args, $instance )
		{
			extract( $args );
			echo $args['before_widget'];
			if ( !empty( $instance['title'] ) ) {
				echo $args['before_title'] . $instance['title'] . $args['after_title'];
			}
			$product_item_class   = array( 'product-item' );
			$product_item_class[] = 'style-1';
			$product_item_class[] = 'rows-space-30';
			$products             = kuteshop_product_query( $instance );
			?>
            <div class="kuteshop-products style-1">
				<?php if ( $products->have_posts() ): ?>
                    <ul class="product-list-grid row auto-clear equal-container better-height">
						<?php while ( $products->have_posts() ) : $products->the_post(); ?>
                            <li <?php wc_product_class( $product_item_class ); ?>>
								<?php wc_get_template_part( 'product-styles/content-product-style', '9' ); ?>
                            </li>
						<?php endwhile; ?>
						<?php wp_reset_postdata(); ?>
                    </ul>
				<?php else: ?>
                    <p>
                        <strong><?php esc_html_e( 'No Product', 'kuteshop-toolkit' ); ?></strong>
                    </p>
				<?php endif; ?>
            </div>
			<?php
			echo $args['after_widget'];
		}

		function update( $new_instance, $old_instance )
		{
			$instance             = $old_instance;
			$instance['title']    = $new_instance['title'];
			$instance['per_page'] = $new_instance['per_page'];
			$instance['order']    = $new_instance['order'];
			$instance['orderby']  = $new_instance['orderby'];
			$instance['target']   = $new_instance['target'];

			return $instance;
		}

		function form( $instance )
		{
			//
			// set defaults
			// -------------------------------------------------
			$instance    = wp_parse_args(
				$instance,
				array(
					'title'    => '',
					'per_page' => '4',
					'order'    => 'DESC',
					'orderby'  => 'date',
					'target'   => 'recent-product',
				)
			);
			$title_value = $instance['title'];
			$title_field = array(
				'id'    => $this->get_field_name( 'title' ),
				'name'  => $this->get_field_name( 'title' ),
				'type'  => 'text',
				'title' => esc_html__( 'Title', 'kuteshop-toolkit' ),
			);
			echo ovic_add_field( $title_field, $title_value );
			$target_value = $instance['target'];
			$target_field = array(
				'id'         => $this->get_field_name( 'target' ),
				'name'       => $this->get_field_name( 'target' ),
				'type'       => 'select',
				'options'    => array(
					'best-selling'      => esc_html__( 'Best Selling Products', 'kuteshop-toolkit' ),
					'top-rated'         => esc_html__( 'Top Rated Products', 'kuteshop-toolkit' ),
					'recent-product'    => esc_html__( 'Recent Products', 'kuteshop-toolkit' ),
					'featured_products' => esc_html__( 'Featured Products', 'kuteshop-toolkit' ),
					'on_sale'           => esc_html__( 'On Sale', 'kuteshop-toolkit' ),
					'on_new'            => esc_html__( 'On New', 'kuteshop-toolkit' ),
				),
				'attributes' => array(
					'data-depend-id' => 'target',
					'style'          => 'width: 100%;',
				),
				'title'      => esc_html__( 'Choose Target', 'kuteshop-toolkit' ),
			);
			echo ovic_add_field( $target_field, $target_value );
			$orderby_value = $instance['orderby'];
			$orderby_field = array(
				'id'         => $this->get_field_name( 'orderby' ),
				'name'       => $this->get_field_name( 'orderby' ),
				'type'       => 'select',
				'options'    => array(
					'date'          => esc_html__( 'Date', 'kuteshop-toolkit' ),
					'ID'            => esc_html__( 'ID', 'kuteshop-toolkit' ),
					'author'        => esc_html__( 'Author', 'kuteshop-toolkit' ),
					'title'         => esc_html__( 'Title', 'kuteshop-toolkit' ),
					'modified'      => esc_html__( 'Modified', 'kuteshop-toolkit' ),
					'rand'          => esc_html__( 'Random', 'kuteshop-toolkit' ),
					'comment_count' => esc_html__( 'Comment count', 'kuteshop-toolkit' ),
					'menu_order'    => esc_html__( 'Menu order', 'kuteshop-toolkit' ),
					'_sale_price'   => esc_html__( 'Sale price', 'kuteshop-toolkit' ),
				),
				'attributes' => array(
					'style' => 'width: 100%;',
				),
				'title'      => esc_html__( 'Order By', 'kuteshop-toolkit' ),
			);
			echo ovic_add_field( $orderby_field, $orderby_value );
			$order_value = $instance['order'];
			$order_field = array(
				'id'         => $this->get_field_name( 'order' ),
				'name'       => $this->get_field_name( 'order' ),
				'type'       => 'select',
				'options'    => array(
					'ASC'  => esc_html__( 'ASC', 'kuteshop-toolkit' ),
					'DESC' => esc_html__( 'DESC', 'kuteshop-toolkit' ),
				),
				'attributes' => array(
					'style' => 'width: 100%;',
				),
				'title'      => esc_html__( 'Order', 'kuteshop-toolkit' ),
			);
			echo ovic_add_field( $order_field, $order_value );
			$per_page_value = $instance['per_page'];
			$per_page_field = array(
				'id'    => $this->get_field_name( 'per_page' ),
				'name'  => $this->get_field_name( 'per_page' ),
				'type'  => 'number',
				'title' => esc_html__( 'Product per page', 'kuteshop-toolkit' ),
			);
			echo ovic_add_field( $per_page_field, $per_page_value );
		}
	}
}
if ( !function_exists( 'Products_Widget_init' ) ) {
	function Products_Widget_init()
	{
		register_widget( 'Products_Widget' );
	}

	add_action( 'widgets_init', 'Products_Widget_init', 2 );
}